@@ -44,7 +44,8 @@ BaghiraConfig::BaghiraConfig(TDEConfig*, TQWidget* parent)
 //     config_ = new TDEConfig("baghirarc");
 //     config_ = new TQSettings;
 //     config_->beginGroup("/baghira/Deco");
-    TDEGlobal::locale()->insertCatalogue("twin_baghira_config");
+    TDEGlobal::locale()->insertCatalogue("twin_clients");
+    TDEGlobal::locale()->insertCatalogue("twin_baghira");
 
     dialog_ = new ConfigDialog(parent);
     buttonDialog_ = new ButtonColors(parent, "Button Colors");
