@@ -176,7 +176,7 @@ bool LiquidStyle::objectEventHandler( const TQStyleControlElementData &ceData,
          }
          else if ( obj->inherits( "TQDockWindow" ) )
          {
-            if (TDEStyle::eventFilter( obj, ev ))
+            if (TQObject::eventFilter( obj, ev ))
                return true;
             TQWidget * w = ( TQWidget * ) obj;
             if ( w->backgroundMode() != TQt::PaletteBackground )
